# History

## 0.1.1
### Fixed
- Improvements in documentation and docstrings.
### Added
- Examples of use incorporated in docstrings of the following functions: make_intervals, classify_events_base_on_time, scale_centroids, calculate_speed, position_of_event, distances_to_position, calculate_sampling_period, calculate_sampling_rate, peh, peri_event_spectogram, normalize_pes, plot_pes, delta_power_spectral, delta_coherence.

## 0.1.2
### Fixed
- Improvements in documentation.

## 0.1.1
### Fixed
- Improvements in documentation.

## 0.1.0
### Added
- First release on PyPI.